==> evolution-1.3.1.zip: evolution-1.3.1/assets/modules/store/lang/italian.php <==
<?php
/*List pack */
$_Lang['version'] = "Versione";
$_Lang['suthor'] = "autore";
$_Lang['date'] = "Rilasciato";
$_Lang['downloads'] = "Caricato";
$_Lang['install'] = "Installa";
$_Lang['reinstall'] = "Resetta";
$_Lang['update'] = "Aggiorna";
$_Lang['installed'] = "stabilito";
$_Lang['installed2'] = "Installato";
$_Lang['exit'] = "Uscire";
$_Lang['alert_overwrite'] = "L'installazione di questo add-on sovrascrive quelli esistenti. Continuare?";

/*Main*/
$_Lang['store_name'] = "Gestione Pacchetti";
$_Lang['version_evailble'] = "Una nuova versione";
$_Lang['category'] = "Categorie";

/*Login form*/
$_Lang['enter_in_own_repository'] = "Accedi alla repository";
$_Lang['password'] = "Password";
$_Lang['enter'] = "Login";
$_Lang['email'] = "E-mail";
$_Lang['register'] = "Registrati";
$_Lang['own_repository'] = "La mia Repository";
$_Lang['login_errors'] = "E-mail o Password errata";

/* & Tpl filters */
$_Lang['s1_1_reated_on'] = "Creato";
$_Lang['s1_2_name'] = "Titolo";
$_Lang['s1_3_position'] = "Posizione";
$_Lang['s1_4_published'] = "Aggiornamento";
$_Lang['s2_1_up'] = "Discendente";
$_Lang['s2_2_down'] = "Ascendente";
$_Lang['search'] = "Cerca nella Categoria: ";

/* faq */
$_Lang['faq'] = '
<li><a href="http://extras.evolution-cms.com/faq/whatfor.html" target="_blank">A cosa serve la repository</a></li>⏎
<li><a href="http://extras.evolution-cms.com/faq/howtoadd.html" target="_blank">Come aggiungere un pacchetto alla repository</a></li>⏎
<li><a href="http://extras.evolution-cms.com/faq/howtocollect.html" target="_blank">Come creare un pacchetto per la installazione</a></li>';

?>

==> evolution-1.4.5.zip: evolution-1.4.5/assets/modules/store/lang/italian.php <==
<?php
/*List pack */
$_Lang['version'] = "Versione";
$_Lang['suthor'] = "autore";
$_Lang['date'] = "Rilasciato";
$_Lang['downloads'] = "Caricato";
$_Lang['install'] = "Installa";
$_Lang['reinstall'] = "Resetta";
$_Lang['update'] = "Aggiorna";
$_Lang['installed'] = "stabilito";
$_Lang['installed2'] = "Installato";
$_Lang['exit'] = "Uscire";
$_Lang['alert_overwrite'] = "L'installazione di questo add-on sovrascrive quelli esistenti. Continuare?";

/*Main*/
$_Lang['store_name'] = "Gestione Pacchetti";
$_Lang['version_evailble'] = "Una nuova versione";
$_Lang['category'] = "Categorie";

/*Login form*/
$_Lang['enter_in_own_repository'] = "Accedi alla repository";
$_Lang['password'] = "Password";
$_Lang['enter'] = "Login";
$_Lang['email'] = "E-mail";
$_Lang['register'] = "Registrati";
$_Lang['own_repository'] = "La mia Repository";
$_Lang['login_errors'] = "E-mail o Password errata";

/* & Tpl filters */
$_Lang['s1_1_reated_on'] = "Creato";
$_Lang['s1_2_name'] = "Titolo";
$_Lang['s1_3_position'] = "Posizione";
$_Lang['s1_4_published'] = "Aggiornamento";
$_Lang['s2_1_up'] = "Discendente";
$_Lang['s2_2_down'] = "Ascendente";
$_Lang['search'] = "Cerca nella Categoria: ";

/* Installazione tramite caricamento file */
$_Lang ['install_file'] = "Installa per file";
$_Lang ['choose_file_msg'] = "Scegli un file da caricare e installare";
$_Lang ['install_file_btn'] = "Installa";
$_Lang ['install_file_success'] = "Installazione riuscita";

/* faq */
$_Lang['faq'] = '
<li><a href="http://extras.evolution-cms.com/faq/whatfor.html" target="_blank">A cosa serve la repository</a></li>⏎
<li><a href="http://extras.evolution-cms.com/faq/howtoadd.html" target="_blank">Come aggiungere un pacchetto alla repository</a></li>⏎
<li><a href="http://extras.evolution-cms.com/faq/howtocollect.html" target="_blank">Come creare un pacchetto per la installazione</a></li>';

?>
